﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Telerik.WinControls;
using Telerik.WinControls.UI;

namespace _1430367_RadScheduler_multiple_icons
{
    public partial class RadForm1 : Telerik.WinControls.UI.RadForm
    {
        public RadForm1()
        {
            InitializeComponent();

            this.radScheduler1.ElementProvider = new MyElementProvider(radScheduler1);
            this.radScheduler1.AppointmentFactory = new CustomAppointmentFactory();
            this.radScheduler1.Appointments.Add(new AppointmentWithIcons(DateTime.Now, DateTime.Now.AddHours(1), "Release meeting"));

        }
        public class MyAppointmentElement : AppointmentElement
        {
            List<LightVisualElement> icons = new List<LightVisualElement>();
            StackLayoutElement stack;

            public MyAppointmentElement(RadScheduler scheduler, SchedulerView view, IEvent appointment) : base(scheduler, view, appointment)
            {
                this.MouseUp += MyAppointmentElement_MouseUp;
            }

            private void MyAppointmentElement_MouseUp(object sender, MouseEventArgs e)
            {
                AppointmentWithIcons app = (AppointmentWithIcons)this.Appointment;
                app.Icons.Add(new Bitmap(@"..\..\Folder1.png"));
                this.Scheduler.SchedulerElement.RefreshViewElement();
                
            }

            protected override Type ThemeEffectiveType
            {
                get
                {
                    return typeof(AppointmentElement);
                }
            }

            protected override void CreateChildElements()
            {
                base.CreateChildElements();

                icons = new List<LightVisualElement>();
                stack = new StackLayoutElement();
                stack.Orientation = Orientation.Vertical;
                stack.Alignment = ContentAlignment.TopRight;
                this.Children.Add(stack);
            }

            public override void Synchronize()
            {
                base.Synchronize();

                AppointmentWithIcons app = (AppointmentWithIcons)this.Appointment;
                foreach (var image in app.Icons)
                {
                    LightVisualElement icon = new LightVisualElement();
                    icon.Image = image;
                    stack.Children.Add(icon);
                }

            }
        }

        public class MyElementProvider : SchedulerElementProvider
        {
            public MyElementProvider(RadScheduler scheduler)
                : base(scheduler)
            {
            }

            protected override T CreateElement<T>(SchedulerView view, object context)
            {
                if (typeof(T) == typeof(AppointmentElement))
                {
                    return new MyAppointmentElement(this.Scheduler, view, (IEvent)context) as T;
                }

                return base.CreateElement<T>(view, context);
            }
        }

        public class CustomAppointmentFactory : IAppointmentFactory
        {
            public IEvent CreateNewAppointment()
            {
                return new AppointmentWithIcons();
            }
        }

        public class AppointmentWithIcons : Appointment
        {
            public AppointmentWithIcons() : base()
            {
            }

            public AppointmentWithIcons(DateTime start, DateTime end, string summary) : base(start, end, summary)
            {
            }

            protected override Event CreateOccurrenceInstance()
            {
                return new AppointmentWithIcons();
            }
            private List<Bitmap> icons = new List<Bitmap>();

            public List<Bitmap> Icons { get => icons; set => icons = value; }
        }
    }
}
